/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.topology;

import org.ow2.petals.topology.generated.Container;
import org.ow2.petals.topology.generated.Domain;
import org.ow2.petals.topology.generated.Topology;

/**
 * @author Adrien Louis - EBM WebSourcing
 */
public final class TopologyHelper {

    /**
     * No constructor available.
     */
    private TopologyHelper() {
        // NOP
    }

    /**
     * Retrieve the container in the given topology
     *
     * @param containerName
     *            may be null
     * @param topology
     *            must be non null
     * @return the container, null if not found
     */
    public static Container findContainer(final String containerName, final Topology topology) {
        return TopologyHelper.findContainer(containerName, topology.getDomain());
    }

    /**
     * Retrieve the container in the given domain
     *
     * @param containerName
     *            may be null
     * @param domain
     *            must be non null
     * @return the container, null if not found
     */
    public static Container findContainer(final String containerName, final Domain domain) {
        Container result = null;
        for (Container container : domain.getContainer()) {
            if (container.getName().equals(containerName)) {
                result = container;
                break;
            }
        }
        return result;
    }

}
