/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.topology;

import static org.junit.Assert.assertNotNull;

import java.io.File;
import java.io.InputStream;
import java.net.URISyntaxException;

import org.junit.Test;

/**
 * @since Petals 1.0
 * @author Nicolas Salatge - EBM WebSourcing
 * @author Roland NAUDIN - EBM WebSourcing
 */
public class TopologyBuilderTest {

    /**
     * Unit test of the {@link TopologyBuilder} about the parsing of a file.
     */
    @Test
    public void testTopologyBuilder_00() throws TopologyException, URISyntaxException {
        final String fileName = new File(Thread.currentThread().getContextClassLoader()
                .getResource("topology.xml").toURI()).getAbsolutePath();
        TopologyBuilder.createTopology(fileName);
    }

    /**
     * Unit test of the {@link TopologyBuilder} about the parsing of an input
     * stream
     */
    @Test
    public void testTopologyBuilder_01() throws TopologyException {
        final InputStream isTopo = Thread.currentThread().getContextClassLoader()
                .getResourceAsStream("topology.xml");
        assertNotNull(isTopo);
        TopologyBuilder.createTopology(isTopo);
    }

    @Test(expected = TopologyException.class)
    public void testTopologyBuilderFail() throws URISyntaxException, TopologyException {
        final String fileName = new File(Thread.currentThread().getContextClassLoader()
                .getResource("topologyError.xml").toURI()).getAbsolutePath();
        TopologyBuilder.createTopology(fileName);
    }
}